/*
 * Copyright 2013 Mark Slater
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */

package net.sourceforge.writexml;

import static net.sourceforge.writexml.ObjectUtils.checkNotNull;

abstract class StringTagContent extends TagContent {

    protected final String value;

    StringTagContent(final String value) {
        this.value = checkNotNull(value, "Illegal attempt to construct with null value");
    }

    @Override
    public final boolean equals(final Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        StringTagContent stringTagContent = getClass().cast(o);
        return value.equals(stringTagContent.value);

    }

    @Override
    public final int hashCode() {
        return value.hashCode();
    }

    @Override
    public final String toString() {
        return getClass().getSimpleName() + "{value='" + value + "'}";
    }

}
